﻿using NUnit.Framework;
using System;
using System.IO;
using System.Linq;

namespace Coscine.WaterbutlerHelper.Tests
{
    [TestFixture]
    public class WaterbutlerTests
    {
        [Test]
        public void DummyTest()
        {
            Assert.True(true);
        }

        //[Test]
        public void Test()
        {
            WaterbutlerInterface waterbuterInterface = new WaterbutlerInterface();
            var authHeader = waterbuterInterface.BuildRdsAuthHeader("3fb662c4-a7ef-42e0-961d-06bfd11c1efd");
            var objectMetadata = waterbuterInterface.GetObjectInfoAsync("/", "rds", authHeader).Result;

            foreach (var info in objectMetadata)
            {
                var result = waterbuterInterface.GetObjectInfoAsync(info, authHeader).Result;
                Assert.True(result != null);
                Assert.True(result.First().IsFile == info.IsFile);
                Assert.True(result.First().IsFolder == info.IsFolder);
            }

            Assert.True(waterbuterInterface.IsFolder("/", "rds", authHeader));
            Assert.False(waterbuterInterface.IsFolder("/doom.jpg", "rds", authHeader));
            Assert.False(waterbuterInterface.IsFolder("/doom2.jpg", "rds", authHeader));

            Assert.False(waterbuterInterface.IsFile("/", "rds", authHeader));
            Assert.True(waterbuterInterface.IsFile("/doom.jpg", "rds", authHeader));
            Assert.True(waterbuterInterface.IsFile("/doom2.jpg", "rds", authHeader));

            var randomFile = Guid.NewGuid();
            var randomFolder = Guid.NewGuid();

            var memoryStream = new MemoryStream();
            byte[] data = { (byte)'C', (byte)'o', (byte)'S', (byte)'I', (byte)'n', (byte)'e'};
            memoryStream.Write(data, 0, data.Length);
            memoryStream.Position = 0;

            var r = waterbuterInterface.UploadFileAsync("/", randomFile.ToString(), "rds", authHeader, memoryStream).Result;
            Assert.True(waterbuterInterface.Exists($"/{randomFile}", "rds", authHeader).Result);
            objectMetadata = waterbuterInterface.GetObjectInfoAsync("/", "rds", authHeader).Result;
            var objectInfo = objectMetadata.Where(x => x.Name == randomFile.ToString()).First();

            using (var dwonloadResponse = waterbuterInterface.DownloadObjectAsync(objectInfo, authHeader).Result)
            {
                Assert.True(dwonloadResponse.IsSuccessStatusCode);
                var temp = new byte[data.Length];
                dwonloadResponse.Content.ReadAsStreamAsync().Result.Read(temp, 0, data.Length);
                Assert.True(Enumerable.SequenceEqual(data, temp));
            }

            _ = waterbuterInterface.DeleteObjectAsync(objectInfo, authHeader).Result;

            Assert.False(waterbuterInterface.Exists($"/{randomFile}", "rds", authHeader).Result);

        }
    }
}
